@@ -1,15 +1,15 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-
 import os
 import sys
 from textwrap import dedent
 from typing import Dict, Tuple
 
+import appconfigpy
 import click
 import msgfy
 import path
@@ -24,7 +24,7 @@ from ._common import DEFAULT_DUP_COL_HANDLER
 from ._config import ConfigKey, app_config_mgr
 from ._const import IPYNB_FORMAT_NAME_LIST, PROGRAM_NAME, ExitCode
 from ._enum import Context, DupDatabase
-from .subcommand import FileConverter, GoogleSheetsConverter, UrlConverter
+from .converter import FileConverter, GoogleSheetsConverter, UrlConverter
 
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"], obj={})
@@ -76,7 +76,7 @@ def initialize_logger(name: str, log_level: int) -> None:
     logger.enable(name)
     ptr.set_logger(True)
     sqlite.set_logger(True)
-    # appconfigpy.set_logger(True)
+    appconfigpy.set_logger(True)
 
 
 def finalize(con, converter, is_create_db: bool) -> int:
