@@ -2,7 +2,6 @@
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-
 from textwrap import dedent
 
 import path
@@ -22,8 +21,8 @@ def valid_json_single_file():
     return file_path
 
 
-def invalid_json_single_file():
-    file_path = "invalid_json_a.json"
+def valid_json_single_b_file():
+    file_path = "singlejson_b.json"
 
     with open(file_path, "w") as f:
         f.write(dedent("""\
@@ -51,6 +50,13 @@ def valid_json_multi_file_1():
                     {"a": 1, "b": 4},
                     {"a": 2 },
                     {"a": 3, "b": 120.9}
+                ],
+                "2018Asset": [
+                    {
+                        "RANK": "1",
+                        "id": "item_entertainment_18_212",
+                        "count": "1billion"
+                    }
                 ]
             }"""))
 
