@@ -2,7 +2,6 @@
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-
 import os
 from textwrap import dedent
 
@@ -14,8 +13,8 @@ from simplesqlite import SimpleSQLite
 from sqliteschema import SQLiteSchemaExtractor
 
 from sqlitebiter._const import ExitCode
+from sqlitebiter.converter._base import SourceInfo
 from sqlitebiter.sqlitebiter import cmd
-from sqlitebiter.subcommand._base import SourceInfo
 
 from .common import print_test_result, print_traceback
 from .dataset import *
@@ -55,7 +54,7 @@ class Test_sqlitebiter_file:
             [valid_utf8_csv_file, ExitCode.SUCCESS],
             [valid_json_symbols, ExitCode.SUCCESS],
             [invalid_csv_file, ExitCode.FAILED_CONVERT],
-            [invalid_json_single_file, ExitCode.NO_INPUT],
+            [valid_json_single_b_file, ExitCode.SUCCESS],
             [invalid_excel_file_1, ExitCode.NO_INPUT],
             [invalid_excel_file_2, ExitCode.FAILED_CONVERT],
             [invalid_html_file, ExitCode.NO_INPUT],
@@ -101,6 +100,7 @@ class Test_sqlitebiter_file:
         with runner.isolated_filesystem():
             files = [
                 valid_json_single_file(),
+                valid_json_single_b_file(),
                 valid_json_multi_file_1(),
                 valid_jsonlines_file(),
                 valid_csv_file_1_1(),
@@ -153,7 +153,6 @@ class Test_sqlitebiter_file:
         with runner.isolated_filesystem():
             files = [
                 invalid_csv_file(),
-                invalid_json_single_file(),
                 invalid_excel_file_1(),
                 invalid_excel_file_2(),
                 invalid_html_file(),
@@ -185,7 +184,7 @@ class Test_sqlitebiter_file:
         with runner.isolated_filesystem():
             files = [
                 valid_json_single_file(),
-                invalid_json_single_file(),
+                valid_json_single_b_file(),
                 valid_json_multi_file_1(),
                 valid_json_kv_file(),
                 valid_csv_file_1_1(),
@@ -209,6 +208,7 @@ class Test_sqlitebiter_file:
 
             con = SimpleSQLite(db_path, "r")
             expected_tables = [
+                "2018Asset",
                 "singlejson",
                 "multij1",
                 "multij2",
@@ -223,6 +223,7 @@ class Test_sqlitebiter_file:
                 "testtitle_html2",
                 "tsv_a",
                 "valid_mdtable_markdown1",
+                "root",
                 SourceInfo.get_table_name(),
             ]
             actual_tables = con.fetch_table_names()
@@ -232,6 +233,7 @@ class Test_sqlitebiter_file:
             assert set(actual_tables) == set(expected_tables)
 
             expected_data_table = {
+                "2018Asset": [(1, "1billion", "item_entertainment_18_212")],
                 "singlejson": [(1, 4.0, "a"), (2, 2.1, "bb"), (3, 120.9, "ccc")],
                 "multij1": [(1, 4.0, "a"), (2, 2.1, "bb"), (3, 120.9, "ccc")],
                 "multij2": [(1, 4.0), (2, None), (3, 120.9)],
@@ -256,7 +258,7 @@ class Test_sqlitebiter_file:
                 "valid_mdtable_markdown1": [(1, 123.1, "a"), (2, 2.2, "bb"), (3, 3.3, "ccc")],
             }
             for table in con.fetch_table_names():
-                if table == SourceInfo.get_table_name():
+                if table in (SourceInfo.get_table_name(), "root"):
                     continue
 
                 result = con.select("*", table_name=table)
