@@ -2,7 +2,6 @@
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-
 from textwrap import dedent
 
 import pytest
@@ -11,8 +10,8 @@ from click.testing import CliRunner
 from simplesqlite import SimpleSQLite
 
 from sqlitebiter._const import ExitCode
+from sqlitebiter.converter._base import SourceInfo
 from sqlitebiter.sqlitebiter import cmd
-from sqlitebiter.subcommand._base import SourceInfo
 
 from .common import print_traceback
 from .dataset import complex_json
